EColor class

Constructors

EColor({required Brightness brightness})

Properties

backgroundColor ↔ Color
getter/setter pair
brightness ↔ Brightness
getter/setter pair
cardColor ↔ Color
getter/setter pair
danger ↔ List<Color>
getter/setter pair
dividerColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
info ↔ List<Color>
getter/setter pair
placeholderText ↔ Color
getter/setter pair
primaryText ↔ Color
getter/setter pair
regularText ↔ Color
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaffoldBackgroundColor ↔ Color
getter/setter pair
secondaryText ↔ Color
getter/setter pair
success ↔ List<Color>
getter/setter pair
themeData → ThemeData
no setter
warning ↔ List<Color>
getter/setter pair

Methods

mergaWith({Color? primaryText, Color? regularText, Color? secondaryText, Color? placeholderText, Color? scaffoldBackgroundColor, Color? backgroundColor}) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited